@@ -43,12 +43,14 @@ struct _Distribution {
 	Phylum *phylum;
 };
 
+extern Phylum lsb_phy;
 extern Phylum debian_phy;
 extern Phylum redhat_phy;
 extern Phylum turbolinux_phy;
 extern Phylum irix_phy;
 
 static Distribution distros[] = {
+	{ "LSB Linux",     "/etc/lsb-release",        &lsb_phy },
 	{ "Slackware",     "/etc/slackware-version",  &debian_phy },
 	{ "Debian",        "/etc/debian_version",     &debian_phy },
 	{ "Mandrake",      "/etc/mandrake-release",   &redhat_phy },
